import execa from 'execa'

export const findLatestVersionOfPackage = async (pkg, cwd) => {
  // React 18 is hardcoded as we don't yet support React 19
  const reactPackages = [
    'react',
    'react-dom',
    '@types/react',
    '@types/react-dom',
  ]

  if (reactPackages.includes(pkg)) {
    return '18'
  }

  const result = await execa(
    'yarn',
    ['-s', '--json', 'info', pkg, 'dist-tags'],
    { cwd }
  )

  try {
    const { data } = JSON.parse(result.stdout)

    return data.latest
  } catch (err) {
    console.log('Error while trying to get latest version:', err)
    console.log('package: %s, stdout: %s', pkg, result.stdout)
    throw err
  }
}

export default {
  findLatestVersionOfPackage,
}
